@@ -85,11 +85,6 @@
 #include "oldlist.h"
 #include "structures.h"
 #include <stdio.h>
-#if MAC_OR_DOS
-#include <stdlib.h>
-#else
-#include "freelist.h"
-#endif
 
 /*----------------------------------------------------------------------
               M a c r o s
@@ -202,12 +197,11 @@ LIST destroy(LIST list) {
  *  Return the space taken by the LISTs of a list to the heap.
  **********************************************************************/
 void destroy_nodes(LIST list, void_dest destructor) {
-  if (destructor == NULL)
-    destructor = memfree;
+  ASSERT_HOST(destructor != NULL);
 
   while (list != NIL_LIST) {
-    (*destructor) (first_node (list));
-    list = pop (list);
+    if (first_node(list) != NULL) (*destructor)(first_node(list));
+    list = pop(list);
   }
 }
 
@@ -401,7 +395,6 @@ LIST s_adjoin(LIST var_list, void *variable, int_compare compare) {
   return (push_last (var_list, variable));
 }
 
-
 /**********************************************************************
  *   s e a r c h
  *
