@@ -38,9 +38,6 @@
 
 #include "allheaders.h"
 
-// Gridsize for word grid when reassigning diacritics to words. Not critical.
-const int kWordGridSize = 50;
-
 #undef EXTERN
 #define EXTERN
 
@@ -254,6 +251,7 @@ void Textord::filter_blobs(ICOORD page_tr,         // top right
       &block->noise_blobs,
       &block->small_blobs,
       &block->large_blobs);
+    if (block->line_size == 0) block->line_size = 1;
     block->line_spacing = block->line_size *
         (tesseract::CCStruct::kDescenderFraction +
          tesseract::CCStruct::kXHeightFraction +
@@ -363,7 +361,7 @@ void Textord::cleanup_nontext_block(BLOCK* block) {
   // Non-text blocks must contain at least one row.
   ROW_IT row_it(block->row_list());
   if (row_it.empty()) {
-    TBOX box = block->bounding_box();
+    const TBOX& box = block->bounding_box();
     float height = box.height();
     inT32 xstarts[2] = {box.left(), box.right()};
     double coeffs[3] = {0.0, 0.0, static_cast<double>(box.bottom())};
@@ -772,6 +770,7 @@ void Textord::TransferDiacriticsToBlockGroups(BLOBNBOX_LIST* diacritic_blobs,
   PointerVector<WordWithBox> word_ptrs;
   for (int g = 0; g < groups.size(); ++g) {
     const BlockGroup* group = groups[g];
+    if (group->bounding_box.null_box()) continue;
     WordGrid word_grid(group->min_xheight, group->bounding_box.botleft(),
                        group->bounding_box.topright());
     for (int b = 0; b < group->blocks.size(); ++b) {
