@@ -80,15 +80,10 @@ bool File::ReadFileToString(const string& filename, string* out) {
   return in.CloseFile();
 }
 
-void File::ReadFileToStringOrDie(const string& filename, string* out) {
-  ASSERT_HOST_MSG(ReadFileToString(filename, out),
-                  "Failed to read file: %s\n", filename.c_str());
-}
-
-
 string File::JoinPath(const string& prefix, const string& suffix) {
-  return (!prefix.size() || prefix[prefix.size() - 1] == '/') ?
-      prefix + suffix : prefix + "/" + suffix;
+  return (prefix.empty() || prefix[prefix.size() - 1] == '/')
+             ? prefix + suffix
+             : prefix + "/" + suffix;
 }
 
 bool File::Delete(const char* pathname) {
